area
	var
		indoors = 1
		list/exits
		list/arrivals = new()
		leftx; rightx
		mapx; mapy


	proc/IsOccupiable(turf/T)
		//is this turf in the area and can players move into it?
		//this proc helps with player and AI movement.
		if((T.loc == src) && (!istype(T, /turf/inaccessible))) return 1


	proc/MakeFootstep()
		//send footsteps to all exits (players in adjacent rooms see indicator)
		for(var/turf/fixture/exit/E in contents)
			E.MakeFootstep()


	proc/InitializeExits()
		//replace the type specified with the actual area of that type.
		for(var/curdir in exits)
			var/area/A = locate(exits[curdir]) in world
			exits[curdir] = A


	proc/InitializeArrivals()
		//assumes all exits/entrances are reciprocal, and that all exits in an area
		//lead to different places!
		for(var/curdir in exits)
			for(var/turf/fixture/exit/T in contents)
				if(T.exitdir == curdir)
					arrivals[exits[curdir]] = T

		//calculate minimum and maximum occupiable x values
		//(for auto-facing players on entry)
		var
			minOK = x + 11
			maxOK = x - 1
			turf/T
			curx

		for(var/offset in 0 to 10)
			curx = x + offset
			T = locate(curx, y, z)
			if(!istype(T, /turf/inaccessible))
				if(curx < minOK) minOK = curx
				if(curx > maxOK) maxOK = curx

		leftx = minOK
		rightx = maxOK

		//sanity check: warn of areas that are defined but not on map
		if(!leftx)
			world << "[src]: unmapped"
		else
			//sanity check: make sure number of exit fixtures on map matches
			//number of declared exits in area definition
			var/totalexits = 0
			for(var/turf/fixture/exit/E in contents) totalexits++
			if(totalexits != length(exits)) world << "[src]: bad exit count"


	Entered(mob/player/M)
		var/madeSound = 0
		//if the mob is a naked fungus, and humans are present, screech and
		//set up mutual accusations
		if(M.icon_state == "fungus")
			for(var/mob/player/P in (contents - M))
				if(P.icon_state == "human")
					M.suspected = 1
					P.suspected = 1
					if(!madeSound)
						src << screechSound
						madeSound = 1

		else if(M.icon_state in actsHuman)
			//if mob is (or acts) human, play suspense sound
			//and, if naked fungi present, set up accusations
			//(yes, a fungus in human form will accuse known fungi)
			for(var/mob/player/P in (contents - M))
				if(P.icon_state == "human")
					if(!madeSound)
						src << musicSound
						madeSound = 1
				else if(P.icon_state == "fungus")
					P.suspected = 1
					M.suspected = 1

		for(var/mob/player/P in world)
			//update display for all watchers -- note that this is key
			//to the current player as well, since live mobs just watch themselves
			if((P.watching == M) && P.client)
				P.client.UpdateEye(src)

		//start/stop the wind sound if needed
		if(M.client)
			if(M.lastarea.indoors != indoors)
				if(!indoors)
					M << windSound
				else
					M << windSilence

		M.lastarea = src

		//make sure the player has proper orientation upon entering area
		if(((M.dir == EAST) && (M.x == rightx)) || \
		((M.dir == WEST) && (M.x == leftx)))
			M.dir = turn(M.dir, 180)


	Bar
		mapx = 17
		mapy = 12
		exits = list("l" = /area/Rec_Room, "u" = /area/Main_Hallway_3)


	Fuel_Depot
		mapx = 31
		mapy = 7
		indoors = 0
		exits = list("u" = /area/Outdoors_6, "d" = /area/Outdoors_12,
		"l" = /area/Outdoors_8)


	Garage
		mapx = 9
		mapy = 26
		exits = list("d" = /area/Garage_Hallway_1, "u" = /area/Outdoors_2)


	Garage_Hallway_1
		mapx = 9
		mapy = 18
		name = "Garage Hallway North"
		exits = list("u" = /area/Garage, "d" = /area/Garage_Hallway_2,
		"l" = /area/Kennel_Hallway_2)


	Garage_Hallway_2
		mapx = 9
		mapy = 15
		name = "Garage Hallway Center"
		exits = list("u" = /area/Garage_Hallway_1, "d" = /area/Garage_Hallway_3,
		"l" = /area/Office, "r" = /area/Main_Hallway_2)


	Garage_Hallway_3
		mapx = 9
		mapy = 9
		name = "Garage Hallway South"
		exits = list("u" = /area/Garage_Hallway_2, "l" = /area/Supply_Room,
		"r" = /area/Outdoors_7)


	Greenhouse
		mapx = 26
		mapy = 18
		exits = list("d" = /area/Radio_Hallway_1, "u" = /area/Outdoors_4)


	Gun_Cabinet
		mapx = 14
		mapy = 18
		exits = list("d" = /area/Main_Hallway_2)


	Infirmary
		mapx = 23
		mapy = 12
		exits = list("l" = /area/Kitchen, "u" = /area/Main_Hallway_5)


	Kennel
		mapx = 6
		mapy = 21
		exits = list("d" = /area/Kennel_Hallway_2)


	Kennel_Hallway_1
		mapx = 3
		mapy = 18
		name = "Kennel Hallway West"
		exits = list("r" = /area/Kennel_Hallway_2, "d" = /area/Outdoors_10)


	Kennel_Hallway_2
		mapx = 6
		mapy = 18
		name = "Kennel Hallway East"
		exits = list("l" = /area/Kennel_Hallway_1, "u" = /area/Kennel,
		"r" = /area/Garage_Hallway_1)


	Kitchen
		mapx = 20
		mapy = 12
		exits = list("u" = /area/Main_Hallway_4, "r" = /area/Infirmary)


	Main_Hallway_2
		mapx = 14
		mapy = 15
		name = "Main Hallway West"
		exits = list("d" = /area/Rec_Room, "r" = /area/Main_Hallway_3,
		"u" = /area/Gun_Cabinet, "l" = /area/Garage_Hallway_2)


	Main_Hallway_3
		mapx = 17
		mapy = 15
		name = "Main Hallway/Quarters Access Junction"
		exits = list("l" = /area/Main_Hallway_2, "d" = /area/Bar,
		"u" = /area/Quarters_Hallway_1, "r" = /area/Main_Hallway_4)


	Main_Hallway_4
		mapx = 20
		mapy = 15
		name = "Main Hallway outside Kitchen"
		exits = list("l" = /area/Main_Hallway_3, "r" = /area/Main_Hallway_5,
		"d" = /area/Kitchen)


	Main_Hallway_5
		mapx = 23
		mapy = 15
		name = "Main Hallway East"
		exits = list("l" = /area/Main_Hallway_4, "r" = /area/Radio_Hallway_1,
		"d" = /area/Infirmary, "u" = /area/Storage)


	Map_Room
		mapx = 29
		mapy = 12
		exits = list("l" = /area/Radio_Hallway_2, "u" = /area/Radio_Room)


	Office
		mapx = 6
		mapy = 15
		exits = list("r" = /area/Garage_Hallway_2)


	Outdoors_1
		mapx = 1
		mapy = 31
		indoors = 0
		name = "Northwest of Compound"
		exits = list("d" = /area/Outdoors_11, "r" = /area/Outdoors_2)


	Outdoors_2
		mapx = 9
		mapy = 31
		name = "Garage Entrance"
		indoors = 0
		exits = list("l" = /area/Outdoors_1, "r" = /area/Outdoors_3,
		"d" = /area/Garage)


	Outdoors_3
		mapx = 13
		mapy = 31
		name = "Quarters Entrance"
		indoors = 0
		exits = list("l" = /area/Outdoors_2, "r" = /area/Outdoors_4,
		"d" = /area/Quarters_Hallway_1)


	Outdoors_4
		mapx = 27
		mapy = 31
		name = "Greenhouse Entrance"
		indoors = 0
		exits = list("l" = /area/Outdoors_3, "r" = /area/Outdoors_5,
		"d" = /area/Greenhouse)


	Outdoors_5
		mapx = 31
		mapy = 31
		name = "Northeast of Compound"
		indoors = 0
		exits = list("l" = /area/Outdoors_4, "d" = /area/Outdoors_6)


	Outdoors_6
		mapx = 31
		mapy = 18
		name = "Southeast of Compound"
		indoors = 0
		exits = list("u" = /area/Outdoors_5, "d" = /area/Fuel_Depot)


	Outdoors_7
		mapx = 17
		mapy = 9
		name = "Main Entrances"
		indoors = 0
		exits = list("l" = /area/Garage_Hallway_3, "r" = /area/Radio_Hallway_3,
		"d" = /area/Outdoors_8)


	Outdoors_8
		mapx = 17
		mapy = 6
		name = "Path to Depot/Outbuildings"
		indoors = 0
		exits = list("u" = /area/Outdoors_7, "d" = /area/Outdoors_9,
		"r" = /area/Fuel_Depot)


	Outdoors_9
		mapx = 17
		mapy = 3
		name = "Path to Shack/Shed"
		indoors = 0
		exits = list("u" = /area/Outdoors_8, "l" = /area/Outdoors_10,
		"r" = /area/Outdoors_12)


	Outdoors_10
		mapx = 5
		mapy = 4
		name = "Kennel Entrance"
		indoors = 0
		exits = list("u" = /area/Kennel_Hallway_1, "d" = /area/Tool_Shed,
		"l" = /area/Outdoors_11, "r" = /area/Outdoors_9)


	Outdoors_11
		mapx = 1
		mapy = 4
		name = "Southwest of Compound"
		indoors = 0
		exits = list("u" = /area/Outdoors_1, "r" = /area/Outdoors_10)


	Outdoors_12
		mapx = 31
		mapy = 4
		name = "Outside Shack"
		indoors = 0
		exits = list("u" = /area/Fuel_Depot, "d" = /area/Shack,
		"l" = /area/Outdoors_9)


	Quarters_Hallway_1
		mapx = 13
		mapy = 26
		name = "Quarters Access Hallway"
		exits = list("d" = /area/Main_Hallway_3, "r" = /area/Quarters_Hallway_2,
		"u" = /area/Outdoors_3)


	Quarters_Hallway_2
		mapx = 16
		mapy = 26
		name = "Quarters Hallway West"
		exits = list("l" = /area/Quarters_Hallway_1, "r" = /area/Quarters_Hallway_3,
		"u" = /area/Sleeping_Quarters_1, "d" = /area/Sleeping_Quarters_4)


	Quarters_Hallway_3
		mapx = 19
		mapy = 26
		name = "Quarters Hallway Center"
		exits = list("l" = /area/Quarters_Hallway_2, "r" = /area/Quarters_Hallway_4,
		"u" = /area/Sleeping_Quarters_2, "d" = /area/Sleeping_Quarters_5)


	Quarters_Hallway_4
		mapx = 22
		mapy = 26
		name = "Quarters Hallway East"
		exits = list("l" = /area/Quarters_Hallway_3, "r" = /area/Storage,
		"u" = /area/Sleeping_Quarters_3, "d" = /area/Sleeping_Quarters_6)


	Radio_Hallway_1
		mapx = 26
		mapy = 15
		name = "Radio Room Hallway North"
		exits = list("d" = /area/Radio_Hallway_2, "l" = /area/Main_Hallway_5,
		"r" = /area/Radio_Room, "u" = /area/Greenhouse)


	Radio_Hallway_2
		mapx = 26
		mapy = 12
		name = "Radio Room Hallway Center"
		exits = list("u" = /area/Radio_Hallway_1, "d" = /area/Radio_Hallway_3,
		"r" = /area/Map_Room)


	Radio_Hallway_3
		mapx = 26
		mapy = 9
		name = "Radio Room Hallway South"
		exits = list("u" = /area/Radio_Hallway_2, "l" = /area/Outdoors_7)


	Radio_Room
		mapx = 29
		mapy = 15
		exits = list("l" = /area/Radio_Hallway_1, "d" = /area/Map_Room)


	Rec_Room
		mapx = 14
		mapy = 12
		exits = list("l" = /area/Water_Closet, "u" = /area/Main_Hallway_2,
		"r" = /area/Bar)


	Shack
		mapx = 31
		mapy = 1
		exits = list("u" = /area/Outdoors_12)


	Sleeping_Quarters_1
		mapx = 16
		mapy = 29
		exits = list("d" = /area/Quarters_Hallway_2)


	Sleeping_Quarters_2
		mapx = 19
		mapy = 29
		exits = list("d" = /area/Quarters_Hallway_3)


	Sleeping_Quarters_3
		mapx = 22
		mapy = 29
		exits = list("d" = /area/Quarters_Hallway_4)


	Sleeping_Quarters_4
		mapx = 16
		mapy = 23
		exits = list("u" = /area/Quarters_Hallway_2)


	Sleeping_Quarters_5
		mapx = 19
		mapy = 23
		exits = list("u" = /area/Quarters_Hallway_3)


	Sleeping_Quarters_6
		mapx = 22
		mapy = 23
		exits = list("u" = /area/Quarters_Hallway_4)


	Storage
		mapx = 25
		mapy = 26
		exits = list("l" = /area/Quarters_Hallway_4, "d" = /area/Main_Hallway_5)


	Supply_Room
		mapx = 6
		mapy = 9
		exits = list("r" = /area/Garage_Hallway_3)


	Tool_Shed
		mapx = 5
		mapy = 1
		exits = list("u" = /area/Outdoors_10)


	Water_Closet
		mapx = 11
		mapy = 12
		exits = list("r" = /area/Rec_Room)

