obj/jet
	//a jet of flame from the flamethrower
	icon = 'jet.dmi'
	animate_movement = NO_STEPS


obj/item
	icon = 'item.dmi'


	proc/Use(mob/player/user)
		//this proc definition is a stub -- each item type implements it differently


	clothing
		icon_state = "clothing"


		Use(mob/player/M)
			//clothing is only useful to a naked fungus
			if(M.icon_state == "fungus")
				M.icon_state = "fake human"
				M.DropCurrentItem()
				del src


	dynamite
		icon_state = "dynamite"


		Use(mob/player/M)
			if(src in M.contents)
				M.DropCurrentItem()
				var/area/A = loc:loc
				//give players fair warning: flickering icon and matchlight sound
				icon_state = "ohcrap"
				layer = FLY_LAYER
				A << fuseSound

				spawn(DYNAMITE_FUSE)
					icon = 'boom.dmi'
					icon_state = null

					world << dynamiteSound
					world << GetAlarmText("Dynamite just exploded in [A]!")

					for(var/mob/player/P in A)
						//don't add extra penalty to killing self with dynamite
						if(M != P)
							M.AdjustScore(P.BlowUpRealGood(), "blowed up [P]")
						else P.BlowUpRealGood()

					spawn(8)
						del src


	fire_axe
		icon_state = "fire axe"


		Use(mob/player/M)
			//first, try to find a target in front of the player
			var/mob/player/target
			var/list/L = M.GetPathAhead()
			if(length(L))
				var/turf/T = L[1]
				for(target in T.contents)
					if(target.icon_state in actsHuman)
						target.DieAsHuman()
						return

			//if no target was available in front, any one will do
			for(target in orange(1))
				if(target.icon_state in actsHuman)
					target.DieAsHuman()
					return


	flamethrower
		icon_state = "flamethrower"
		var/list/jets = list()
		var/usable = 1


		New()
			. = ..()
			//jets are created up front to reduce overhead during gameplay
			//(probably not necessary, but might as well)
			for(var/i in 1 to 10)
				jets += new /obj/jet()


		Use(mob/player/M)
			//the "usable" flag appears in various places in this game to prevent
			//the player from "spamming"
			if(!usable) return
			usable = 0
			var/obj/jet/J
			spawn(FLAMETHROWER_DELAY)
				usable = 1
				for(J in jets) J.loc = src

			var/list/path = M.GetPathAhead()
			var/mob/player/target = null
			var/curJet = 0

			if(length(path))
				//look at each turf in path, closest first
				M.loc:loc << flamethrowerSound
				for(var/turf/curT in path)
					J = jets[++curJet]
					J.loc = curT

					//check to see if mob in the turf are roastable
					for(target in curT)
						if(target.icon_state in roastable)
							M.AdjustScore(target.Roast(), "roasted [target]")


	pistol
		icon_state = "pistol"
		var/usable = 1


		Use(mob/player/M)
			if(!usable) return
			usable = 0
			spawn(PISTOL_DELAY)
				usable = 1

			var/list/path = M.GetPathAhead()
			var/mob/player
				found = null
				target = null
			var/range = 0

			if(length(path))
				//look at each turf in path, closest first
				for(var/turf/curT in path)
					++range
					//check to see if a mob in the turf is human (or pretending)
					for(target in curT)
						if(target.icon_state in actsHuman)
							found = target
							break

					//if we found a candidate, don't look at any more turfs
					if(found) break

			world << pistolSound
			world << GetAlarmText("A pistol shot rings out from [M.loc:loc]!")

			if(found)
				//range 1 = 100% accuracy, range 2 = 50%, 3 = 33%, etc.
				if(prob(100 / range))
					M.AdjustScore(target.DieAsHuman(), "simple murder of [target]")
				else
					M << GetSystemText("Missed!")


proc/GetAlarmText(T)
	//generate impassioned text
	return "<font color=[ALARMCOLOR]>[T]</font>"


proc/GetSystemText(T)
	//generate dispassionate text
	return "<font color=[SYSTEMCOLOR]>[T]</font>"


